@@ -46,8 +46,7 @@ from gwpy.segments import (
 from gwpy.table import EventTable
 from gwpy.table.filters import in_segmentlist
 
-from .. import cli
-from ..const import DEFAULT_SEGMENT_SERVER
+from ..utils import cli
 from ..io import html as htmlio
 from ..io.datafind import get_data
 from ..omega import batch
@@ -68,7 +67,7 @@ use('Agg')
 
 # backend-dependent imports
 from gwpy.plot import Plot  # noqa: E402
-from ..plot import texify  # noqa: E402
+from ..utils.plot import texify  # noqa: E402
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 __credits__ = 'Siddharth Soni <siddharth.soni@ligo.org>' \
@@ -285,7 +284,6 @@ def main(args=None):
     if args.state_flag is not None:
         state = DataQualityFlag.query(
             args.state_flag, int(args.gpsstart), int(args.gpsend),
-            url=DEFAULT_SEGMENT_SERVER,
         ).coalesce()
         statea = []
         padding = args.segment_start_pad + args.segment_end_pad
@@ -669,7 +667,7 @@ def main(args=None):
         page.div(class_='card border-%s mb-1 shadow-sm' % context)
         page.div(class_='card-header text-white bg-%s' % context)
         page.a(channel, class_='collapsed card-link cis-link',
-               href='#osem%s' % i, **{'data-toggle': 'collapse'})
+               href='#osem%s' % i, **{'data-bs-toggle': 'collapse'})
         page.div.close()  # card-header
         page.div(id_='osem%s' % i, class_='collapse',
                  **{'data-parent': '#osems-group'})
